@@ -75,18 +75,18 @@ struct {
   struct { int WrMove; } WrClass;
 } * _m3_exporters;
 
-extern _MODULE MM_ASCII;
 extern _MODULE MI_ASCII;
-extern _MODULE MM_Abs;
+extern _MODULE MM_ASCII;
 extern _MODULE MI_Abs;
+extern _MODULE MM_Abs;
 extern _MODULE MM_AddExpr;
 extern _MODULE MI_AddExpr;
 extern _MODULE MI_Addr;
 extern _MODULE MM_Addr;
-extern _MODULE MI_AddressExpr;
 extern _MODULE MM_AddressExpr;
-extern _MODULE MI_Adr;
+extern _MODULE MI_AddressExpr;
 extern _MODULE MM_Adr;
+extern _MODULE MI_Adr;
 extern _MODULE MM_AdrSize;
 extern _MODULE MI_AdrSize;
 extern _MODULE MM_AndExpr;
@@ -95,10 +95,10 @@ extern _MODULE MM_Arg;
 extern _MODULE MI_Arg;
 extern _MODULE MM_ArrayExpr;
 extern _MODULE MI_ArrayExpr;
-extern _MODULE MM_ArrayType;
 extern _MODULE MI_ArrayType;
-extern _MODULE MM_AssertStmt;
+extern _MODULE MM_ArrayType;
 extern _MODULE MI_AssertStmt;
+extern _MODULE MM_AssertStmt;
 extern _MODULE MM_AssignStmt;
 extern _MODULE MI_AssignStmt;
 extern _MODULE MM_Atom;
@@ -108,64 +108,65 @@ extern _MODULE MI_AtomAtomTbl;
 extern _MODULE MM_AtomList;
 extern _MODULE MI_AtomList;
 extern _MODULE MI_BasicCtypes;
-extern _MODULE MM_BitSize;
 extern _MODULE MI_BitSize;
+extern _MODULE MM_BitSize;
 extern _MODULE MM_BldFace;
 extern _MODULE MI_BldFace;
 extern _MODULE MI_BldHooks;
 extern _MODULE MM_BldHooks;
-extern _MODULE MM_BldPosix;
 extern _MODULE MI_BldPosix;
+extern _MODULE MM_BldPosix;
 extern _MODULE MI_BldQRep;
 extern _MODULE MM_BldQuake;
 extern _MODULE MI_BldQuake;
-extern _MODULE MM_BldWin32;
 extern _MODULE MI_BldWin32;
+extern _MODULE MM_BldWin32;
 extern _MODULE MM_BlockStmt;
 extern _MODULE MI_BlockStmt;
 extern _MODULE MI_Bool;
 extern _MODULE MM_Bool;
-extern _MODULE MM_BuiltinOps;
 extern _MODULE MI_BuiltinOps;
-extern _MODULE MM_BuiltinTypes;
+extern _MODULE MM_BuiltinOps;
 extern _MODULE MI_BuiltinTypes;
-extern _MODULE MI_ByteSize;
+extern _MODULE MM_BuiltinTypes;
 extern _MODULE MM_ByteSize;
+extern _MODULE MI_ByteSize;
 extern _MODULE MM_CChar;
 extern _MODULE MI_CChar;
-extern _MODULE MM_CConvert;
 extern _MODULE MI_CConvert;
+extern _MODULE MM_CConvert;
 extern _MODULE MM_CG;
 extern _MODULE MI_CG;
-extern _MODULE MM_CallExpr;
 extern _MODULE MI_CallExpr;
+extern _MODULE MM_CallExpr;
 extern _MODULE MM_CallStmt;
 extern _MODULE MI_CallStmt;
-extern _MODULE MM_Card;
 extern _MODULE MI_Card;
+extern _MODULE MM_Card;
 extern _MODULE MM_CaseStmt;
 extern _MODULE MI_CaseStmt;
-extern _MODULE MM_CastExpr;
 extern _MODULE MI_CastExpr;
+extern _MODULE MM_CastExpr;
 extern _MODULE MM_Ceiling;
 extern _MODULE MI_Ceiling;
 extern _MODULE MI_Cerrno;
-extern _MODULE MI_CheckExpr;
 extern _MODULE MM_CheckExpr;
-extern _MODULE MM_CoffTime;
+extern _MODULE MI_CheckExpr;
 extern _MODULE MI_CoffTime;
-extern _MODULE MI_CompareExpr;
+extern _MODULE MM_CoffTime;
 extern _MODULE MM_CompareExpr;
+extern _MODULE MI_CompareExpr;
 extern _MODULE MM_ConcatExpr;
 extern _MODULE MI_ConcatExpr;
-extern _MODULE MI_ConsExpr;
 extern _MODULE MM_ConsExpr;
+extern _MODULE MI_ConsExpr;
 extern _MODULE MM_Constant;
 extern _MODULE MI_Constant;
-extern _MODULE MI_Convert;
 extern _MODULE MM_Convert;
-extern _MODULE MM_Coverage;
+extern _MODULE MI_Convert;
 extern _MODULE MI_Coverage;
+extern _MODULE MM_Coverage;
+extern _MODULE MI_Csetjmp;
 extern _MODULE MI_Cstddef;
 extern _MODULE MI_Cstdlib;
 extern _MODULE MI_Cstring;
@@ -174,34 +175,34 @@ extern _MODULE MM_Dec;
 extern _MODULE MI_Dec;
 extern _MODULE MM_Decl;
 extern _MODULE MI_Decl;
-extern _MODULE MM_DerefExpr;
 extern _MODULE MI_DerefExpr;
+extern _MODULE MM_DerefExpr;
 extern _MODULE MI_Dispose;
 extern _MODULE MM_Dispose;
-extern _MODULE MI_DivExpr;
 extern _MODULE MM_DivExpr;
+extern _MODULE MI_DivExpr;
 extern _MODULE MI_DivideExpr;
 extern _MODULE MM_DivideExpr;
-extern _MODULE MM_DragonInt;
 extern _MODULE MI_DragonInt;
+extern _MODULE MM_DragonInt;
 extern _MODULE MI_DragonT;
 extern _MODULE MM_DragonT;
-extern _MODULE MM_EReel;
 extern _MODULE MI_EReel;
+extern _MODULE MM_EReel;
 extern _MODULE MI_ESet;
 extern _MODULE MM_ESet;
-extern _MODULE MI_ETimer;
 extern _MODULE MM_ETimer;
-extern _MODULE MM_EnumElt;
+extern _MODULE MI_ETimer;
 extern _MODULE MI_EnumElt;
+extern _MODULE MM_EnumElt;
 extern _MODULE MI_EnumExpr;
 extern _MODULE MM_EnumExpr;
-extern _MODULE MM_EnumType;
 extern _MODULE MI_EnumType;
-extern _MODULE MM_Env;
+extern _MODULE MM_EnumType;
 extern _MODULE MI_Env;
-extern _MODULE MI_EqualExpr;
+extern _MODULE MM_Env;
 extern _MODULE MM_EqualExpr;
+extern _MODULE MI_EqualExpr;
 extern _MODULE MI_ErrType;
 extern _MODULE MM_ErrType;
 extern _MODULE MM_Error;
@@ -210,17 +211,17 @@ extern _MODULE MM_EvalStmt;
 extern _MODULE MI_EvalStmt;
 extern _MODULE MM_Exceptionz;
 extern _MODULE MI_Exceptionz;
-extern _MODULE MM_ExitStmt;
 extern _MODULE MI_ExitStmt;
+extern _MODULE MM_ExitStmt;
 extern _MODULE MI_Expr;
 extern _MODULE MM_Expr;
 extern _MODULE MM_ExprParse;
 extern _MODULE MI_ExprParse;
 extern _MODULE MI_ExprRep;
-extern _MODULE MI_Extended;
 extern _MODULE MM_Extended;
-extern _MODULE MI_ExtendedFloat;
+extern _MODULE MI_Extended;
 extern _MODULE MM_ExtendedFloat;
+extern _MODULE MI_ExtendedFloat;
 extern _MODULE MM_External;
 extern _MODULE MI_External;
 extern _MODULE MI_FPU;
@@ -233,38 +234,38 @@ extern _MODULE MM_Field;
 extern _MODULE MI_File;
 extern _MODULE MI_FilePosix;
 extern _MODULE MM_FilePosix;
-extern _MODULE MI_FileRd;
 extern _MODULE MM_FileRd;
-extern _MODULE MI_FileWr;
+extern _MODULE MI_FileRd;
 extern _MODULE MM_FileWr;
-extern _MODULE MI_Fingerprint;
+extern _MODULE MI_FileWr;
 extern _MODULE MM_Fingerprint;
-extern _MODULE MM_First;
+extern _MODULE MI_Fingerprint;
 extern _MODULE MI_First;
+extern _MODULE MM_First;
 extern _MODULE MI_FloatMode;
 extern _MODULE MM_FloatMode;
 extern _MODULE MM_Floatt;
 extern _MODULE MI_Floatt;
-extern _MODULE MI_Floor;
 extern _MODULE MM_Floor;
+extern _MODULE MI_Floor;
 extern _MODULE MI_Fmt;
 extern _MODULE MM_Fmt;
 extern _MODULE MM_FmtBuf;
 extern _MODULE MI_FmtBuf;
 extern _MODULE MI_FmtBufF;
 extern _MODULE MI_FmtBufTest;
-extern _MODULE MI_ForStmt;
 extern _MODULE MM_ForStmt;
-extern _MODULE MM_Formal;
+extern _MODULE MI_ForStmt;
 extern _MODULE MI_Formal;
+extern _MODULE MM_Formal;
 extern _MODULE MI_Host;
 extern _MODULE MM_Host;
-extern _MODULE MI_Ident;
 extern _MODULE MM_Ident;
+extern _MODULE MI_Ident;
 extern _MODULE MI_IfStmt;
 extern _MODULE MM_IfStmt;
-extern _MODULE MI_InExpr;
 extern _MODULE MM_InExpr;
+extern _MODULE MI_InExpr;
 extern _MODULE MM_Inc;
 extern _MODULE MI_Inc;
 extern _MODULE MM_Int;
@@ -273,36 +274,36 @@ extern _MODULE MI_IntArraySort;
 extern _MODULE MM_IntArraySort;
 extern _MODULE MM_IntIntTbl;
 extern _MODULE MI_IntIntTbl;
-extern _MODULE MI_IntM3LibsTbl;
 extern _MODULE MM_IntM3LibsTbl;
+extern _MODULE MI_IntM3LibsTbl;
 extern _MODULE MM_IntMapTbl;
 extern _MODULE MI_IntMapTbl;
-extern _MODULE MM_IntRefTbl;
 extern _MODULE MI_IntRefTbl;
-extern _MODULE MM_IntTextTbl;
+extern _MODULE MM_IntRefTbl;
 extern _MODULE MI_IntTextTbl;
-extern _MODULE MI_Integer;
+extern _MODULE MM_IntTextTbl;
 extern _MODULE MM_Integer;
+extern _MODULE MI_Integer;
 extern _MODULE MI_IntegerExpr;
 extern _MODULE MM_IntegerExpr;
-extern _MODULE MM_IsType;
 extern _MODULE MI_IsType;
+extern _MODULE MM_IsType;
 extern _MODULE MM_KeywordExpr;
 extern _MODULE MI_KeywordExpr;
-extern _MODULE MI_LReel;
 extern _MODULE MM_LReel;
+extern _MODULE MI_LReel;
 extern _MODULE MI_Last;
 extern _MODULE MM_Last;
 extern _MODULE MM_Lib;
 extern _MODULE MI_Lib;
-extern _MODULE MI_LibSeq;
 extern _MODULE MM_LibSeq;
+extern _MODULE MI_LibSeq;
 extern _MODULE MI_LibSeqRep;
 extern _MODULE MI_Location;
-extern _MODULE MI_LockStmt;
 extern _MODULE MM_LockStmt;
-extern _MODULE MI_LongFloat;
+extern _MODULE MI_LockStmt;
 extern _MODULE MM_LongFloat;
+extern _MODULE MI_LongFloat;
 extern _MODULE MM_LongReal;
 extern _MODULE MI_LongReal;
 extern _MODULE MI_LongRealRep;
@@ -314,12 +315,12 @@ extern _MODULE MM_M3;
 extern _MODULE MI_M3;
 extern _MODULE MM_M3BackPosix;
 extern _MODULE MI_M3Backend;
-extern _MODULE MI_M3Buf;
 extern _MODULE MM_M3Buf;
-extern _MODULE MM_M3CG;
+extern _MODULE MI_M3Buf;
 extern _MODULE MI_M3CG;
-extern _MODULE MI_M3CG_Check;
+extern _MODULE MM_M3CG;
 extern _MODULE MM_M3CG_Check;
+extern _MODULE MI_M3CG_Check;
 extern _MODULE MI_M3CG_Ops;
 extern _MODULE MI_M3CG_Wr;
 extern _MODULE MM_M3CG_Wr;
@@ -329,19 +330,19 @@ extern _MODULE MI_M3Config;
 extern _MODULE MM_M3Driver;
 extern _MODULE MI_M3Driver;
 extern _MODULE MI_M3DriverRep;
-extern _MODULE MI_M3FP;
 extern _MODULE MM_M3FP;
+extern _MODULE MI_M3FP;
 extern _MODULE MI_M3File;
 extern _MODULE MM_M3File;
 extern _MODULE MI_M3Header;
 extern _MODULE MM_M3Header;
-extern _MODULE MM_M3ID;
 extern _MODULE MI_M3ID;
+extern _MODULE MM_M3ID;
 extern _MODULE MI_M3Libs;
-extern _MODULE MI_M3Path;
 extern _MODULE MM_M3Path;
-extern _MODULE MM_M3RT;
+extern _MODULE MI_M3Path;
 extern _MODULE MI_M3RT;
+extern _MODULE MM_M3RT;
 extern _MODULE MM_M3String;
 extern _MODULE MI_M3String;
 extern _MODULE MM_M3Timers;
@@ -351,8 +352,8 @@ extern _MODULE MM_M3toC;
 extern _MODULE MI_M3toC;
 extern _MODULE MM_Main;
 extern _MODULE MI_Main;
-extern _MODULE MI_Marker;
 extern _MODULE MM_Marker;
+extern _MODULE MI_Marker;
 extern _MODULE MI_Max;
 extern _MODULE MM_Max;
 extern _MODULE MM_Method;
@@ -361,141 +362,141 @@ extern _MODULE MI_MethodExpr;
 extern _MODULE MM_MethodExpr;
 extern _MODULE MI_Min;
 extern _MODULE MM_Min;
-extern _MODULE MM_ModExpr;
 extern _MODULE MI_ModExpr;
+extern _MODULE MM_ModExpr;
 extern _MODULE MI_Module;
 extern _MODULE MM_Module;
 extern _MODULE MM_Msg;
 extern _MODULE MI_Msg;
 extern _MODULE MI_MultiplyExpr;
 extern _MODULE MM_MultiplyExpr;
-extern _MODULE MM_Mutex;
 extern _MODULE MI_Mutex;
-extern _MODULE MM_Mx;
+extern _MODULE MM_Mutex;
 extern _MODULE MI_Mx;
-extern _MODULE MM_MxCheck;
+extern _MODULE MM_Mx;
 extern _MODULE MI_MxCheck;
+extern _MODULE MM_MxCheck;
 extern _MODULE MI_MxGen;
-extern _MODULE MI_MxGenC;
 extern _MODULE MM_MxGenC;
-extern _MODULE MM_MxGenCG;
+extern _MODULE MI_MxGenC;
 extern _MODULE MI_MxGenCG;
+extern _MODULE MM_MxGenCG;
 extern _MODULE MI_MxGenRep;
 extern _MODULE MM_MxGenRep;
 extern _MODULE MM_MxIO;
 extern _MODULE MI_MxIO;
-extern _MODULE MI_MxIn;
 extern _MODULE MM_MxIn;
+extern _MODULE MI_MxIn;
 extern _MODULE MM_MxMap;
 extern _MODULE MI_MxMap;
-extern _MODULE MI_MxMerge;
 extern _MODULE MM_MxMerge;
-extern _MODULE MI_MxOut;
+extern _MODULE MI_MxMerge;
 extern _MODULE MM_MxOut;
-extern _MODULE MM_MxRep;
+extern _MODULE MI_MxOut;
 extern _MODULE MI_MxRep;
+extern _MODULE MM_MxRep;
 extern _MODULE MM_MxSet;
 extern _MODULE MI_MxSet;
 extern _MODULE MM_MxVS;
 extern _MODULE MI_MxVS;
-extern _MODULE MI_MxVSSet;
 extern _MODULE MM_MxVSSet;
-extern _MODULE MI_NamedExpr;
+extern _MODULE MI_MxVSSet;
 extern _MODULE MM_NamedExpr;
+extern _MODULE MI_NamedExpr;
 extern _MODULE MI_NamedType;
 extern _MODULE MM_NamedType;
-extern _MODULE MM_Narrow;
 extern _MODULE MI_Narrow;
+extern _MODULE MM_Narrow;
 extern _MODULE MI_NegateExpr;
 extern _MODULE MM_NegateExpr;
 extern _MODULE MM_New;
 extern _MODULE MI_New;
-extern _MODULE MI_NilChkExpr;
 extern _MODULE MM_NilChkExpr;
-extern _MODULE MM_NotExpr;
+extern _MODULE MI_NilChkExpr;
 extern _MODULE MI_NotExpr;
-extern _MODULE MI_Null;
+extern _MODULE MM_NotExpr;
 extern _MODULE MM_Null;
-extern _MODULE MM_Number;
+extern _MODULE MI_Null;
 extern _MODULE MI_Number;
+extern _MODULE MM_Number;
 extern _MODULE MI_OSError;
-extern _MODULE MM_OSErrorPosix;
 extern _MODULE MI_OSErrorPosix;
+extern _MODULE MM_OSErrorPosix;
 extern _MODULE MM_ObjectAdr;
 extern _MODULE MI_ObjectAdr;
-extern _MODULE MM_ObjectRef;
 extern _MODULE MI_ObjectRef;
+extern _MODULE MM_ObjectRef;
 extern _MODULE MI_ObjectType;
 extern _MODULE MM_ObjectType;
-extern _MODULE MM_OpaqueType;
 extern _MODULE MI_OpaqueType;
+extern _MODULE MM_OpaqueType;
 extern _MODULE MM_OpenArrayType;
 extern _MODULE MI_OpenArrayType;
 extern _MODULE MM_OrExpr;
 extern _MODULE MI_OrExpr;
-extern _MODULE MM_Ord;
 extern _MODULE MI_Ord;
-extern _MODULE MI_PackedType;
+extern _MODULE MM_Ord;
 extern _MODULE MM_PackedType;
-extern _MODULE MM_Params;
+extern _MODULE MI_PackedType;
 extern _MODULE MI_Params;
+extern _MODULE MM_Params;
 extern _MODULE MI_Pathname;
 extern _MODULE MM_PathnamePosix;
-extern _MODULE MM_Pipe;
 extern _MODULE MI_Pipe;
+extern _MODULE MM_Pipe;
 extern _MODULE MM_PipePosix;
 extern _MODULE MM_PlusExpr;
 extern _MODULE MI_PlusExpr;
-extern _MODULE MI_Poly;
 extern _MODULE MM_Poly;
-extern _MODULE MM_PolyBasis;
+extern _MODULE MI_Poly;
 extern _MODULE MI_PolyBasis;
-extern _MODULE MI_ProcBody;
+extern _MODULE MM_PolyBasis;
 extern _MODULE MM_ProcBody;
-extern _MODULE MM_ProcExpr;
+extern _MODULE MI_ProcBody;
 extern _MODULE MI_ProcExpr;
-extern _MODULE MM_ProcType;
+extern _MODULE MM_ProcExpr;
 extern _MODULE MI_ProcType;
+extern _MODULE MM_ProcType;
 extern _MODULE MM_Procedure;
 extern _MODULE MI_Procedure;
 extern _MODULE MI_Process;
 extern _MODULE MM_ProcessPosix;
-extern _MODULE MI_QCode;
 extern _MODULE MM_QCode;
+extern _MODULE MI_QCode;
 extern _MODULE MM_QCompiler;
 extern _MODULE MI_QCompiler;
 extern _MODULE MI_QMachRep;
-extern _MODULE MM_QMachine;
 extern _MODULE MI_QMachine;
+extern _MODULE MM_QMachine;
 extern _MODULE MM_QScanner;
 extern _MODULE MI_QScanner;
 extern _MODULE MI_QToken;
 extern _MODULE MM_QToken;
-extern _MODULE MM_QVSeq;
 extern _MODULE MI_QVSeq;
+extern _MODULE MM_QVSeq;
 extern _MODULE MI_QVSeqRep;
-extern _MODULE MM_QVTbl;
 extern _MODULE MI_QVTbl;
+extern _MODULE MM_QVTbl;
 extern _MODULE MI_QVal;
 extern _MODULE MM_QVal;
 extern _MODULE MI_QValue;
 extern _MODULE MM_QValue;
 extern _MODULE MI_Quake;
 extern _MODULE MM_Quake;
-extern _MODULE MM_QualifyExpr;
 extern _MODULE MI_QualifyExpr;
+extern _MODULE MM_QualifyExpr;
 extern _MODULE MM_RT0;
 extern _MODULE MI_RT0;
-extern _MODULE MI_RT0u;
 extern _MODULE MM_RT0u;
+extern _MODULE MI_RT0u;
 extern _MODULE MM_RTAllocStats;
 extern _MODULE MI_RTAllocStats;
 extern _MODULE MM_RTAllocator;
 extern _MODULE MI_RTAllocator;
 extern _MODULE MM_RTArgs;
 extern _MODULE MI_RTArgs;
-extern _MODULE MI_RTCollector;
 extern _MODULE MM_RTCollector;
+extern _MODULE MI_RTCollector;
 extern _MODULE MI_RTCollectorSRC;
 extern _MODULE MI_RTExRep;
 extern _MODULE MI_RTException;
@@ -505,14 +506,14 @@ extern _MODULE MM_RTHeap;
 extern _MODULE MM_RTHeapDep;
 extern _MODULE MI_RTHeapDep;
 extern _MODULE MI_RTHeapEvent;
-extern _MODULE MI_RTHeapInfo;
 extern _MODULE MM_RTHeapInfo;
+extern _MODULE MI_RTHeapInfo;
 extern _MODULE MM_RTHeapMap;
 extern _MODULE MI_RTHeapMap;
 extern _MODULE MI_RTHeapRep;
 extern _MODULE MM_RTHeapRep;
-extern _MODULE MM_RTHooks;
 extern _MODULE MI_RTHooks;
+extern _MODULE MM_RTHooks;
 extern _MODULE MM_RTIO;
 extern _MODULE MI_RTIO;
 extern _MODULE MM_RTLinker;
@@ -530,13 +531,13 @@ extern _MODULE MM_RTParams;
 extern _MODULE MI_RTParams;
 extern _MODULE MI_RTPerfTool;
 extern _MODULE MM_RTPerfTool;
-extern _MODULE MM_RTProcedure;
 extern _MODULE MI_RTProcedure;
+extern _MODULE MM_RTProcedure;
 extern _MODULE MI_RTProcedureSRC;
 extern _MODULE MM_RTProcess;
 extern _MODULE MI_RTProcess;
-extern _MODULE MI_RTSignal;
 extern _MODULE MM_RTSignal;
+extern _MODULE MI_RTSignal;
 extern _MODULE MI_RTStack;
 extern _MODULE MM_RTThread;
 extern _MODULE MI_RTThread;
@@ -544,8 +545,8 @@ extern _MODULE MI_RTThreadInit;
 extern _MODULE MM_RTThreadStk;
 extern _MODULE MI_RTType;
 extern _MODULE MM_RTType;
-extern _MODULE MI_RTTypeMap;
 extern _MODULE MM_RTTypeMap;
+extern _MODULE MI_RTTypeMap;
 extern _MODULE MI_RTTypeSRC;
 extern _MODULE MI_RTWeakRef;
 extern _MODULE MM_RTutils;
@@ -560,77 +561,77 @@ extern _MODULE MM_RdImpl;
 extern _MODULE MM_RdMove;
 extern _MODULE MI_Real;
 extern _MODULE MM_Real;
-extern _MODULE MI_RealFloat;
 extern _MODULE MM_RealFloat;
+extern _MODULE MI_RealFloat;
 extern _MODULE MI_RealRep;
 extern _MODULE MM_RecordExpr;
 extern _MODULE MI_RecordExpr;
-extern _MODULE MM_RecordType;
 extern _MODULE MI_RecordType;
-extern _MODULE MI_Reel;
+extern _MODULE MM_RecordType;
 extern _MODULE MM_Reel;
-extern _MODULE MM_ReelExpr;
+extern _MODULE MI_Reel;
 extern _MODULE MI_ReelExpr;
+extern _MODULE MM_ReelExpr;
 extern _MODULE MM_RefType;
 extern _MODULE MI_RefType;
 extern _MODULE MI_Refany;
 extern _MODULE MM_Refany;
-extern _MODULE MM_Reff;
 extern _MODULE MI_Reff;
+extern _MODULE MM_Reff;
 extern _MODULE MI_RegularFile;
 extern _MODULE MM_RegularFile;
 extern _MODULE MI_RepeatStmt;
 extern _MODULE MM_RepeatStmt;
 extern _MODULE MM_ReturnStmt;
 extern _MODULE MI_ReturnStmt;
-extern _MODULE MM_Revelation;
 extern _MODULE MI_Revelation;
-extern _MODULE MM_Round;
+extern _MODULE MM_Revelation;
 extern _MODULE MI_Round;
+extern _MODULE MM_Round;
 extern _MODULE MI_Runtime;
 extern _MODULE MM_Runtime;
 extern _MODULE MM_Scanner;
 extern _MODULE MI_Scanner;
 extern _MODULE MI_Scheduler;
 extern _MODULE MI_SchedulerPosix;
-extern _MODULE MI_Scope;
 extern _MODULE MM_Scope;
-extern _MODULE MM_SetExpr;
+extern _MODULE MI_Scope;
 extern _MODULE MI_SetExpr;
-extern _MODULE MM_SetType;
+extern _MODULE MM_SetExpr;
 extern _MODULE MI_SetType;
+extern _MODULE MM_SetType;
 extern _MODULE MI_Stdio;
 extern _MODULE MM_Stdio;
-extern _MODULE MM_Stmt;
 extern _MODULE MI_Stmt;
+extern _MODULE MM_Stmt;
 extern _MODULE MI_StmtRep;
-extern _MODULE MM_Subarray;
 extern _MODULE MI_Subarray;
+extern _MODULE MM_Subarray;
 extern _MODULE MI_SubrangeType;
 extern _MODULE MM_SubrangeType;
 extern _MODULE MM_SubscriptExpr;
 extern _MODULE MI_SubscriptExpr;
-extern _MODULE MI_SubtractExpr;
 extern _MODULE MM_SubtractExpr;
-extern _MODULE MI_TFloat;
+extern _MODULE MI_SubtractExpr;
 extern _MODULE MM_TFloat;
-extern _MODULE MI_TInt;
+extern _MODULE MI_TFloat;
 extern _MODULE MM_TInt;
-extern _MODULE MI_TWord;
+extern _MODULE MI_TInt;
 extern _MODULE MM_TWord;
+extern _MODULE MI_TWord;
 extern _MODULE MI_Target;
 extern _MODULE MM_Target;
 extern _MODULE MM_TargetMap;
 extern _MODULE MI_TargetMap;
-extern _MODULE MI_Terminal;
 extern _MODULE MM_Terminal;
+extern _MODULE MI_Terminal;
 extern _MODULE MM_Text;
 extern _MODULE MI_Text;
 extern _MODULE MM_TextExpr;
 extern _MODULE MI_TextExpr;
 extern _MODULE MI_TextF;
-extern _MODULE MI_TextIntTbl;
 extern _MODULE MM_TextIntTbl;
+extern _MODULE MI_TextIntTbl;
 extern _MODULE MI_TextList;
 extern _MODULE MM_TextList;
 extern _MODULE MI_TextLocTbl;
@@ -644,54 +645,53 @@ extern _MODULE MI_TextTextTbl;
 extern _MODULE MM_TextTextTbl;
 extern _MODULE MM_TextWr;
 extern _MODULE MI_TextWr;
-extern _MODULE MM_Textt;
 extern _MODULE MI_Textt;
+extern _MODULE MM_Textt;
 extern _MODULE MI_Thread;
 extern _MODULE MI_ThreadEvent;
 extern _MODULE MI_ThreadF;
 extern _MODULE MM_ThreadPosix;
 extern _MODULE MI_Time;
-extern _MODULE MI_TimePosix;
 extern _MODULE MM_TimePosix;
+extern _MODULE MI_TimePosix;
 extern _MODULE MI_Tipe;
 extern _MODULE MM_Tipe;
-extern _MODULE MM_TipeDesc;
 extern _MODULE MI_TipeDesc;
-extern _MODULE MM_TipeMap;
+extern _MODULE MM_TipeDesc;
 extern _MODULE MI_TipeMap;
+extern _MODULE MM_TipeMap;
 extern _MODULE MM_Token;
 extern _MODULE MI_Token;
-extern _MODULE MM_Tracer;
 extern _MODULE MI_Tracer;
+extern _MODULE MM_Tracer;
 extern _MODULE MI_Trunc;
 extern _MODULE MM_Trunc;
-extern _MODULE MI_TryFinStmt;
 extern _MODULE MM_TryFinStmt;
-extern _MODULE MI_TryStmt;
+extern _MODULE MI_TryFinStmt;
 extern _MODULE MM_TryStmt;
-extern _MODULE MM_Type;
+extern _MODULE MI_TryStmt;
 extern _MODULE MI_Type;
+extern _MODULE MM_Type;
 extern _MODULE MI_TypeCaseStmt;
 extern _MODULE MM_TypeCaseStmt;
-extern _MODULE MM_TypeExpr;
 extern _MODULE MI_TypeExpr;
+extern _MODULE MM_TypeExpr;
 extern _MODULE MM_TypeFP;
 extern _MODULE MI_TypeFP;
 extern _MODULE MI_TypeRep;
-extern _MODULE MM_TypeTbl;
 extern _MODULE MI_TypeTbl;
+extern _MODULE MM_TypeTbl;
 extern _MODULE MM_Typecode;
 extern _MODULE MI_Typecode;
 extern _MODULE MI_Udir;
-extern _MODULE MM_Uerror;
 extern _MODULE MI_Uerror;
 extern _MODULE MI_Uexec;
 extern _MODULE MI_Uframe;
 extern _MODULE MI_Umman;
 extern _MODULE MM_Unit;
 extern _MODULE MI_Unit;
-extern _MODULE MI_Unix;
 extern _MODULE MM_Unix;
+extern _MODULE MI_Unix;
 extern _MODULE MM_UnsafeHash;
 extern _MODULE MI_UnsafeRd;
 extern _MODULE MI_UnsafeWr;
@@ -699,70 +699,70 @@ extern _MODULE MI_Uprocess;
 extern _MODULE MI_Uresource;
 extern _MODULE MI_UserProc;
 extern _MODULE MM_UserProc;
-extern _MODULE MM_Usignal;
 extern _MODULE MI_Usignal;
+extern _MODULE MM_Usignal;
 extern _MODULE MI_Ustat;
-extern _MODULE MI_Utils;
 extern _MODULE MM_Utils;
+extern _MODULE MI_Utils;
 extern _MODULE MI_Utime;
 extern _MODULE MM_Utypes;
 extern _MODULE MI_Utypes;
 extern _MODULE MI_Uucontext;
 extern _MODULE MI_Uugid;
 extern _MODULE MI_Uuio;
-extern _MODULE MI_Val;
 extern _MODULE MM_Val;
-extern _MODULE MI_Value;
+extern _MODULE MI_Val;
 extern _MODULE MM_Value;
+extern _MODULE MI_Value;
 extern _MODULE MI_ValueRep;
-extern _MODULE MM_VarExpr;
 extern _MODULE MI_VarExpr;
+extern _MODULE MM_VarExpr;
 extern _MODULE MI_Variable;
 extern _MODULE MM_Variable;
 extern _MODULE MM_WebFile;
 extern _MODULE MI_WebFile;
 extern _MODULE MM_WebInfo;
 extern _MODULE MI_WebInfo;
-extern _MODULE MM_WhileStmt;
 extern _MODULE MI_WhileStmt;
-extern _MODULE MM_WithStmt;
+extern _MODULE MM_WhileStmt;
 extern _MODULE MI_WithStmt;
-extern _MODULE MI_Word;
+extern _MODULE MM_WithStmt;
 extern _MODULE MM_Word;
-extern _MODULE MM_WordAnd;
+extern _MODULE MI_Word;
 extern _MODULE MI_WordAnd;
-extern _MODULE MI_WordDivide;
+extern _MODULE MM_WordAnd;
 extern _MODULE MM_WordDivide;
+extern _MODULE MI_WordDivide;
 extern _MODULE MI_WordExtract;
 extern _MODULE MM_WordExtract;
-extern _MODULE MI_WordGE;
 extern _MODULE MM_WordGE;
-extern _MODULE MM_WordGT;
+extern _MODULE MI_WordGE;
 extern _MODULE MI_WordGT;
+extern _MODULE MM_WordGT;
 extern _MODULE MI_WordInsert;
 extern _MODULE MM_WordInsert;
 extern _MODULE MI_WordLE;
 extern _MODULE MM_WordLE;
-extern _MODULE MM_WordLT;
 extern _MODULE MI_WordLT;
+extern _MODULE MM_WordLT;
 extern _MODULE MM_WordMinus;
 extern _MODULE MI_WordMinus;
 extern _MODULE MI_WordMod;
 extern _MODULE MM_WordMod;
 extern _MODULE MM_WordModule;
 extern _MODULE MI_WordModule;
-extern _MODULE MM_WordNot;
 extern _MODULE MI_WordNot;
+extern _MODULE MM_WordNot;
 extern _MODULE MI_WordOr;
 extern _MODULE MM_WordOr;
 extern _MODULE MI_WordPlus;
 extern _MODULE MM_WordPlus;
 extern _MODULE MM_WordRotate;
 extern _MODULE MI_WordRotate;
-extern _MODULE MM_WordShift;
 extern _MODULE MI_WordShift;
-extern _MODULE MM_WordTimes;
+extern _MODULE MM_WordShift;
 extern _MODULE MI_WordTimes;
+extern _MODULE MM_WordTimes;
 extern _MODULE MI_WordXor;
 extern _MODULE MM_WordXor;
 extern _MODULE MI_Wr;
@@ -781,18 +781,18 @@ static _MODULE *_modules[695] = {
   &MI_ThreadEvent,
   &MI_Uframe,
   &MI_RTThread,
-  &MI_Cerrno,
   &MI_RTThreadInit,
   &MI_SchedulerPosix,
   &MI_Scheduler,
   &MI_Usignal,
   &MI_Umman,
-  &MI_RTStack,
   &MI_PolyBasis,
   &MI_Poly,
   &MI_Fingerprint,
   &MI_RTProcedure,
   &MI_RTProcedureSRC,
+  &MI_RTStack,
+  &MI_Csetjmp,
   &MI_RTExRep,
   &MI_RTException,
   &MI_RTProcess,
@@ -804,7 +804,7 @@ static _MODULE *_modules[695] = {
   &MI_RTTypeMap,
   &MI_RTMapOp,
   &MI_Uuio,
-  &MI_Uerror,
+  &MI_Cerrno,
   &MI_Utime,
   &MI_Unix,
   &MI_RTOS,
@@ -862,7 +862,6 @@ static _MODULE *_modules[695] = {
   &MM_RTParams,
   &MM_RTMapOp,
   &MM_RTTypeMap,
-  &MM_Uerror,
   &MM_Unix,
   &MM_RTOS,
   &MM_RTIO,
@@ -958,6 +957,8 @@ static _MODULE *_modules[695] = {
 
   &MI_Udir,
 
+  &MI_Uerror,
+
   &MI_Uugid,
 
   &MI_Terminal,
